pub trait LatticeRef {
type T;
// Required methods
fn pjoin(&self, other: &Self) -> AlgebraicResult<Self::T>;
fn pmeet(&self, other: &Self) -> AlgebraicResult<Self::T>;
}Expand description
Implements algebraic behavior on a reference to a Lattice type, such as a smart pointer that can’t hold ownership
Required Associated Types
Required Methods
fn pjoin(&self, other: &Self) -> AlgebraicResult<Self::T>
fn pmeet(&self, other: &Self) -> AlgebraicResult<Self::T>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".